CountingAnimation class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CountingAnimation
Constructors
- CountingAnimation({Key? key, required String value, required TextStyle textStyle, MainAxisAlignment mainAlignment = MainAxisAlignment.center, int scrollCount = 40, Duration singleScollDuration = const Duration(milliseconds: 50), Duration lastDuration = const Duration(milliseconds: 50), Color bgColor = Colors.transparent, bool useChar = false, bool useRefresh = true})
-
const
Properties
- bgColor → Color
-
widget back ground color. default : transparent
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lastDuration → Duration
-
duration for last animation. default : 50ms
final
- mainAlignment → MainAxisAlignment
-
Main AxisAligment
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollCount → int
-
total amount of play to scroll animation. defalut : 40
final
- singleScollDuration → Duration
-
duration for each scroll animation. default : 50ms
final
- textStyle → TextStyle
-
Text style
final
- useChar → bool
-
value have non-animation character. default: false
final
- useRefresh → bool
-
restart animation when value changed. default : true
final
- value → String
-
Show number value
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CountingAnimation> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited